package com.jiayue.ssi.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jiayue.ssi.entity.SysUser;
import com.jiayue.ssi.service.SysUserService;
import com.jiayue.ssi.util.ResponseVO;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 用户信息controller
 *
 * @author xsl
 * @version 3.0
 */
@RestController
@RequestMapping("/sysUserController" )
@Slf4j
public class SysUserController {
    @Autowired
    SysUserService sysUserService;

    /**
     * 获取用户分页信息
     *
     * @return 用户信息
     */

    @GetMapping(value = "/getAll")
    public ResponseVO getAll(Integer currentPage, Integer pageSize, String username,String password,String status) {
        try {
            QueryWrapper<SysUser> wrapper = new QueryWrapper<>();
            if(StringUtils.isNotEmpty(username)){
                wrapper.eq("username",username);
            }
            if(StringUtils.isNotEmpty(password)){
                wrapper.eq("password",password);
            }
            if(StringUtils.isNotEmpty(status)){
                wrapper.eq("status",status);
            }
            Page<SysUser> result = sysUserService.page(new Page<>(currentPage,pageSize),wrapper);
            return ResponseVO.success(result);
        } catch (Exception e) {
            e.printStackTrace();
            log.error(" 获取所有用户异常");
            return ResponseVO.error(null);
        }
    }

    /**
     * 新增用户
     */
    @PostMapping
    public ResponseVO add(@RequestBody SysUser user, HttpServletRequest request) {
        if (StringUtils.isEmpty(user.getUsername())){
            return ResponseVO.fail("用户账号不能为空!");
        }
        else if (sysUserService.queryUserName(user.getUsername())!=null){
            return ResponseVO.fail(user.getUsername() + "账号已存在！");
        }

        if (StringUtils.isEmpty(user.getPhonenumber())) {
            return ResponseVO.fail("手机号码不能为空！");
        }
        if (StringUtils.isEmpty(user.getNickname())) {
            return ResponseVO.fail("姓名不能为空！");
        }

        if (StringUtils.isEmpty(user.getMailbox())){
            return ResponseVO.fail("邮箱不能为空!");
        }
        else if (sysUserService.queryMailBox(user.getMailbox())!=null){
            return ResponseVO.fail(user.getMailbox() + "邮箱已存在！");
        }

//        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
        // 生成初始密码

        return ResponseVO.success(sysUserService.save(user));
    }
//    /**
//     * 保存用户信息
//     *
//     * @param sysUser 参数
//     * @return 执行结果
//     */
//    @PostMapping(value = "sysUser/")
//    public ResponseVO save(@RequestBody SysUser sysUser) {
//        try {
//            boolean bo = sysUserService.saveUser(sysUser);
//            if (bo){
//                return ResponseVO.success("保存用户信息成功");
//            }
//            else{
//                log.error("保存用户信息失败");
//                return ResponseVO.fail();
//            }
//        } catch (Exception e) {
//            e.printStackTrace();
//            log.error("保存用户信息异常");
//            return ResponseVO.fail("保存用户信息异常");
//        }
//    }

    /**
     * 更新用户信息
     *
     * @param sysUser 参数
     * @return 执行结果
     */
    @PutMapping(value = "sysUser/")
    public ResponseVO update(@RequestBody SysUser sysUser) {
        try {
            boolean bo = sysUserService.updateUser(sysUser);
            if (bo){
                return ResponseVO.success("修改用户信息成功");
            }
            else{
                log.error("更新用户信息失败");
                return ResponseVO.fail();
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("更新用户信息异常");
            return ResponseVO.fail();
        }
    }

    /**
     * 删除用户信息
     *
     * @param ids 删除id
     * @return 执行结果
     */
    @DeleteMapping(value = "sysUser/{ids}")
    public ResponseVO delete(@PathVariable("ids") String ids) {
        try {
            boolean bo = sysUserService.deleteUser(ids);
            if (bo){
                return ResponseVO.success("删除用户信息成功");
            }
            else{
                log.error("删除用户信息失败");
                return ResponseVO.fail();
            }
        } catch (Exception e) {
            e.printStackTrace();
            log.error("删除用户信息异常");
            return ResponseVO.fail("删除用户信息异常");
        }
    }
}
